FlogSession class
La grabación completa de un flujo: metadatos + pantallas + taps + transiciones.
Es lo que se serializa a manifest.json dentro del bundle exportado.
Constructors
-
FlogSession({required String id, required String appName, required int startedAtMs, required DeviceInfo device, int? endedAtMs, List<
FlogScreen> ? screens, List<TapEvent> ? taps, List<NavEdge> ? edges, List<FlogError> ? errors, List<FlogEvent> ? events, Map<String, dynamic> ? meta}) -
FlogSession.fromJson(Map<
String, dynamic> json) -
factory
Properties
- appName → String
-
final
- device → DeviceInfo
-
final
-
edges
→ List<
NavEdge> -
final
- endedAtMs ↔ int?
-
getter/setter pair
-
errors
→ List<
FlogError> -
final
-
events
→ List<
FlogEvent> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
meta
→ Map<
String, dynamic> -
Metadata libre de la sesión (appVersion, build, userId, locale, osVersion…).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
screens
→ List<
FlogScreen> -
final
- startedAtMs → int
-
final
-
taps
→ List<
TapEvent> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited